camelot.camelot.model.authentication.Person.Admin

Package camelot :: Package camelot :: Package model :: Module authentication :: Class Person :: Class Admin |
[hide private]
[frames] | no frames]

# Class Admin

source code

Instance Methods | [hide private]
Inherited from `view.elixir_admin.EntityAdmin`: `__init__`, `__str__`, `createFormView`, `createNewView`, `createSelectView`, `createTableView`, `createValidator`, `getColumns`, `getFieldAttributes`, `getFields`, `getFilters`, `getForm`, `getFormActions`, `getListCharts`, `getModelThread`, `getName`, `getRelatedEntityAdmin`, `getSubclasses`, `setDefaults` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables | [hide private]
| name = `'Persons'`
| section = `'relations'`
| list_display = `['username', 'first_name', 'last_name',]`
| list_filter = `['is_active', 'is_staff', 'is_superuser']`
| form = `TabForm([('Basic', Form([HBoxForm([Form(['username', 'f`...``
Inherited from `Party.Admin`: `field_attributes`, `fields` Inherited from `view.elixir_admin.EntityAdmin`: `form_actions`, `form_display`, `form_size`, `form_title_column`, `list_actions`, `list_charts`, `list_size`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### form Value:
      TabForm([('Basic', Form([HBoxForm([Form(['username', 'first_name', 'la
      st_name', 'sex']), Form(['is_staff', 'is_active', 'is_superuser',]), F
      orm(['picture',]),]), 'contact_mechanisms', 'comment',], scrollbars= T
      rue)), ('Official', Form(['birthdate', 'social_security_number', 'pass
      port_number', 'passport_expiry_date', 'addresses',], scrollbars= True)
      ), ('Work', Form(['employers', 'directed_organizations', 'shares'], sc
      rollbars= True))])